import React from 'react';
import { motion } from 'framer-motion';
import { MessageCircle } from 'lucide-react';
import { useSettingsStore } from '../store/settingsStore';
import { getWhatsAppLink } from '../constants';

const Hero = () => {
  const { homepage } = useSettingsStore();
  const { hero } = homepage;

  const scrollToCategories = () => {
    const element = document.getElementById('categories');
    if (element) {
      const headerOffset = 80;
      const elementPosition = element.getBoundingClientRect().top;
      const offsetPosition = elementPosition + window.pageYOffset - headerOffset;

      window.scrollTo({
        top: offsetPosition,
        behavior: 'smooth'
      });
    }
  };

  return (
    <div className="relative min-h-screen flex items-center justify-center pt-16 overflow-hidden">
      {/* Background Image with Overlay */}
      <div className="absolute inset-0 z-0">
        <img
          src={hero.backgroundImage}
          alt="Çeşme Plajı"
          className="w-full h-full object-cover"
          loading="eager"
          fetchpriority="high"
        />
        <div className="absolute inset-0 bg-black bg-opacity-40"></div>
      </div>

      <div className="container mx-auto px-4 relative z-20">
        <motion.div
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5 }}
          className="text-center max-w-5xl mx-auto text-white"
        >
          {/* Main Title */}
          <h1 className="text-4xl md:text-5xl lg:text-7xl font-black mb-6 leading-tight">
            <span className="text-white">Çeşme ve Alaçatı'da</span>
            <br />
            <span className="text-white">Premium </span>
            <span className="text-yellow-400">Rezervasyon</span>
            <br />
            <span className="text-white">Deneyimi</span>
          </h1>
          
          {/* Subtitle */}
          <p className="text-xl md:text-2xl mb-12 font-medium text-gray-100 max-w-4xl mx-auto leading-relaxed">
            Beach club'lar, tekne turları, restoranlar ve butik oteller için en iyi fiyat garantisi
          </p>
          
          {/* Action Buttons */}
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: 0.2, duration: 0.3 }}
            className="flex flex-col sm:flex-row justify-center gap-6 mb-16"
          >
            <button 
              onClick={scrollToCategories}
              className="px-8 py-4 bg-yellow-500 text-black font-bold rounded-full text-lg hover:bg-yellow-400 transition-all shadow-lg transform hover:scale-105"
            >
              Kategorileri Keşfet →
            </button>
            
            <a
              href={getWhatsAppLink()}
              target="_blank"
              rel="noopener noreferrer"
              className="px-8 py-4 border-2 border-white text-white font-bold rounded-full text-lg hover:bg-white hover:text-black transition-all shadow-lg transform hover:scale-105 flex items-center justify-center"
            >
              WhatsApp'tan Rezervasyon Yap
            </a>
          </motion.div>

          {/* Trust Badges */}
          <div className="flex flex-wrap justify-center gap-8">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ delay: 0.3, duration: 0.3 }}
              className="flex items-center bg-white bg-opacity-15 backdrop-blur-sm px-6 py-3 rounded-full border border-white border-opacity-20"
            >
              <div className="h-8 w-8 rounded-full bg-green-500 flex items-center justify-center mr-3">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 text-white" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                </svg>
              </div>
              <span className="text-white font-semibold">%100 Onaylı Mekanlar</span>
            </motion.div>
            
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ delay: 0.4, duration: 0.3 }}
              className="flex items-center bg-white bg-opacity-15 backdrop-blur-sm px-6 py-3 rounded-full border border-white border-opacity-20"
            >
              <div className="h-8 w-8 rounded-full bg-yellow-500 flex items-center justify-center mr-3">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 text-black" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 7h.01M7 3h5c.512 0 1.024.195 1.414.586l7 7a2 2 0 010 2.828l-7 7a2 2 0 01-2.828 0l-7-7A1.994 1.994 0 013 12V7a4 4 0 014-4z" />
                </svg>
              </div>
              <span className="text-white font-semibold">Şeffaf Fiyat Garantisi</span>
            </motion.div>
            
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ delay: 0.5, duration: 0.3 }}
              className="flex items-center bg-white bg-opacity-15 backdrop-blur-sm px-6 py-3 rounded-full border border-white border-opacity-20"
            >
              <div className="h-8 w-8 rounded-full bg-blue-500 flex items-center justify-center mr-3">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 text-white" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 8v4l3 3m6-3a9 9 0 11-18 0 9 9 0 0118 0z" />
                </svg>
              </div>
              <span className="text-white font-semibold">2 Dakikada Yanıt</span>
            </motion.div>
          </div>
        </motion.div>
      </div>
    </div>
  );
};

export default Hero;